@@ -2,4 +2,4 @@ from os.path import dirname, abspath, join
 
 PROJECT_PATH = join(dirname(abspath(__file__)), '..')
 
-RESOURCE_PATH = join(PROJECT_PATH, 'resources')
+RESOURCE_PATH = join(PROJECT_PATH, 'sinling', 'resources')
